@@ -46,6 +46,8 @@ def _unparse(node: ast.expr) -> str:
         return '[{}]'.format(', '.join(_unparse(elt) for elt in node.elts))
     elif isinstance(node, ast.NameConstant):
         return repr(node.value)
+    elif isinstance(node, ast.BinOp) and isinstance(node.op, ast.BitOr):
+        return f'{_unparse(node.left)} | {_unparse(node.right)}'
     else:
         raise NotImplementedError(ast.dump(node))
 
